#Contributing

Contributions of all kinds are welcome.

Please file any suggestions for contributions by reporting an issue at https://github.com/tobiasvonderhaar/polyan/issues.

##Adding additional cell types
The minimum informaton required to run polyan for a particular organism is 
-The total number of ribosomes per cell
-The total number of transcrpts per cell
-A high quality reference dataset for mRNA expression levels
-A reference file with gene names for the organism
Additionally, a high quality experimental polysome profile can be used to define what a good polysome profile shold look like.

##Report bugs
If you are reporting a bug, please include:
- Your operating system name and version.
- Any details about your local setup that might be helpful in troubleshooting.
- Detailed steps to reproduce the bug.

## Suggest new features
If you have any ideas for functionality to be added to the software you can suggest this as a new feature. Please explain in detail what the feature would do and how it might work. We cannot guarantee that we can quickly act on such suggestions, but you can always help with the implementation!

### Submit Feedback
The best way to send feedback is to file this as an issue, and feedback is always welcome.
